==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/atlantis/dialogs_pl.lua <==

dialogId("sp-v-no0", "font_big", "Lo and behold!")
dialogStr("Zobacz tylko!")


dialogId("sp-m-no1", "font_small", "Just imagine!")
dialogStr("Wyobrażasz sobie?!")


dialogId("sp-v-kdoby", "font_big", "Who could have guessed?!")
dialogStr("W życiu bym na to nie wpadł!")


dialogId("sp-m-neopatrnost", "font_small", "Such carelessness.")
dialogStr("Cóż za niedbalstwo.")


dialogId("sp-v-zahynuli", "font_big", "Thousands perished - the whole city disappeared in the waves because of such ineptness.")
dialogStr("Tysiące ludzi zginęło, całe miasto skryło się w falach z powodu takiej głupoty!")


dialogId("sp-m-vytazeny", "font_small", "Unplugged plug.")
dialogStr("Wyciągnięty korek...")


dialogId("sp-v-trapne", "font_big", "An embarrassing blunder.")
dialogStr("Żenujące niedopatrzenie.")


dialogId("sp-m-costim", "font_small", "What are we to do with it?")
dialogStr("I co z nim zrobimy?")


dialogId("sp-v-vratit0", "font_big", "We can try to put it back in place.")
dialogStr("Możemy spróbować wcisnąć go z powrotem.")


dialogId("sp-m-vratit0", "font_small", "And then? Shall we drink the water that poured in, or what?")
dialogStr("I co potem? Niby co mamy zrobić z wodą, która się wlała? Wypić ją?")


dialogId("sp-v-vratit1", "font_big", "We can put it back in place as a token of our esteem of the citizens` heroic effort to keep it afloat. As a memorial to their industrious, adroit and... persistent nature.")
dialogStr("Możemy włożyć go na miejsce jako dowód naszego uznania dla heroizmu obywateli próbujących utrzymać miasto na wodzie. Jako wspomnienie ich pracowitości, zręczności i... wytrwałości.")


dialogId("sp-m-vratit1", "font_small", "Of what? 'Where are you running? I need to order eight swords.` The Providence itself unplugged that hole. Just imagine you`d hear such things at home. Day by day.")
dialogStr("Czego? 'Dokąd lecisz? Po sześć mieczy.` Wyobraź sobie, że musiałbyś słuchać takich bredni w domu. Dzień w dzień. To Opatrzność wyjęła ten korek.")


dialogId("sp-m-kalet", "font_small", "And moreover: is it likely that anybody would ever come here? Only sepias will nibble it occasionally.")
dialogStr("Poza tym, myślisz, że ktoś tu jeszcze przyjdzie? Tylko mątwy będą go od czasu do czasu podgryzać.")


dialogId("sp-v-pocit", "font_big", "We are going to feel good about it.")
dialogStr("Będzie nam z tym dobrze.")


dialogId("sp-m-potize", "font_small", "We are going to feel down about it. Do you think the boss is going to believe it? A giant unplugged plug? And what have you done with it? We plugged it again. He, he, he.")
dialogStr("Nie będzie nam z tym dobrze. Myślisz, że szef nam uwierzy? 'Wyciągnięty wielki korek? I co z tym zrobiliście? Wetknęliśmy z powrotem.` Ha, ha, ha.")


dialogId("sp-v-vzit", "font_big", "You might be right. Maybe it would be better to take it along.")
dialogStr("Może i masz rację. Może byłoby lepiej zabrać go ze sobą.")


dialogId("sp-m-taky", "font_small", "I think so, too.")
dialogStr("Też tak myślę.")


dialogId("sp-v-dotoho", "font_big", "Let `s get to work.")
dialogStr("Bierzmy się do roboty")


dialogId("sp-m-nechat", "font_small", "What if we just leave that plug here?")
dialogStr("A może zostawmy tu ten korek?")


dialogId("sp-v-centrala", "font_big", "What would the Agency say?")
dialogStr("Co na to powie Centrala?")


dialogId("sp-v-jedno", "font_big", "I don`t think I mind what the boss is going to think about me.")
dialogStr("Nie dbam o to, co szef o mnie myśli.")


dialogId("sp-m-vydrz", "font_small", "Hold on. We are sure to solve it.")
dialogStr("Zaczekaj. Jestem pewna, że to rozwiążemy.")


dialogId("sp-m-spunt", "font_small", "The darned plug. What if we just make up something.")
dialogStr("Cholerny korek. Może po prostu coś zmyślimy?")


dialogId("sp-v-co", "font_big", "Like what, for example?")
dialogStr("Na przykład co?")


dialogId("sp-m-vymluva0", "font_small", "Well, we could say that the city in fact never existed.")
dialogStr("Moglibyśmy powiedzieć, że tak naprawdę miasto nigdy nie istniało.")


dialogId("sp-m-vymluva1", "font_small", "Well, we could say that the city sank because the Arctic ice had melted.")
dialogStr("Moglibyśmy powiedzieć, że miasto zatonęło w wyniku topnienia lądolodu Arktyki.")


dialogId("sp-m-vymluva2", "font_small", "An earthquake could have sunk the city, for example.")
dialogStr("Na przykład trzęsienie ziemi mogło zatopić miasto.")


dialogId("sp-m-vymluva3", "font_small", "A tsunami might have sunk the city, for example.")
dialogStr("Na przykład tsunami mogło zatopić miasto.")


dialogId("sp-m-vymluva4", "font_small", "We could try to say that a volcano erupted in the center of the city.")
dialogStr("Moglibyśmy powiedzieć, że w samym środku miasta wybuchł wulkan.")


dialogId("sp-v-nesmysl", "font_big", "That is just nonsense.")
dialogStr("Bez sensu.")


dialogId("sp-v-ven", "font_big", "This time our goal is to get that plug out.")
dialogStr("Tym razem naszym zadaniem jest wydostać stąd ten korek.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/atlantis/dialogs_pl.lua <==

dialogId("sp-v-no0", "font_big", "Lo and behold!")
dialogStr("Zobacz tylko!")


dialogId("sp-m-no1", "font_small", "Just imagine!")
dialogStr("Wyobrażasz sobie?!")


dialogId("sp-v-kdoby", "font_big", "Who could have guessed?!")
dialogStr("W życiu bym na to nie wpadł!")


dialogId("sp-m-neopatrnost", "font_small", "Such carelessness.")
dialogStr("Cóż za niedbalstwo.")


dialogId("sp-v-zahynuli", "font_big", "Thousands perished - the whole city disappeared in the waves because of such ineptness.")
dialogStr("Tysiące ludzi zginęło, całe miasto skryło się w falach z powodu takiej głupoty!")


dialogId("sp-m-vytazeny", "font_small", "Unplugged plug.")
dialogStr("Wyciągnięty korek...")


dialogId("sp-v-trapne", "font_big", "An embarrassing blunder.")
dialogStr("Żenujące niedopatrzenie.")


dialogId("sp-m-costim", "font_small", "What are we to do with it?")
dialogStr("I co z nim zrobimy?")


dialogId("sp-v-vratit0", "font_big", "We can try to put it back in place.")
dialogStr("Możemy spróbować wcisnąć go z powrotem.")


dialogId("sp-m-vratit0", "font_small", "And then? Shall we drink the water that poured in, or what?")
dialogStr("I co potem? Niby co mamy zrobić z wodą, która się wlała? Wypić ją?")


dialogId("sp-v-vratit1", "font_big", "We can put it back in place as a token of our esteem of the citizens’ heroic effort to keep it afloat. As a memorial to their industrious, adroit and... persistent nature.")
dialogStr("Możemy włożyć go na miejsce jako dowód naszego uznania dla heroizmu obywateli próbujących utrzymać miasto na wodzie. Jako wspomnienie ich pracowitości, zręczności i... wytrwałości.")


dialogId("sp-m-vratit1", "font_small", "Of what? 'Where are you running? I need to order eight swords.’ The Providence itself unplugged that hole. Just imagine you’d hear such things at home. Day by day.")
dialogStr("Czego? 'Dokąd lecisz? Po sześć mieczy.’ Wyobraź sobie, że musiałbyś słuchać takich bredni w domu. Dzień w dzień. To Opatrzność wyjęła ten korek.")


dialogId("sp-m-kalet", "font_small", "And moreover: is it likely that anybody would ever come here? Only sepias will nibble it occasionally.")
dialogStr("Poza tym, myślisz, że ktoś tu jeszcze przyjdzie? Tylko mątwy będą go od czasu do czasu podgryzać.")


dialogId("sp-v-pocit", "font_big", "We are going to feel good about it.")
dialogStr("Będzie nam z tym dobrze.")


dialogId("sp-m-potize", "font_small", "We are going to feel down about it. Do you think the boss is going to believe it? A giant unplugged plug? And what have you done with it? We plugged it again. He, he, he.")
dialogStr("Nie będzie nam z tym dobrze. Myślisz, że szef nam uwierzy? 'Wyciągnięty wielki korek? I co z tym zrobiliście? Wetknęliśmy z powrotem.’ Ha, ha, ha.")


dialogId("sp-v-vzit", "font_big", "You might be right. Maybe it would be better to take it along.")
dialogStr("Może i masz rację. Może byłoby lepiej zabrać go ze sobą.")


dialogId("sp-m-taky", "font_small", "I think so, too.")
dialogStr("Też tak myślę.")


dialogId("sp-v-dotoho", "font_big", "Let ’s get to work.")
dialogStr("Bierzmy się do roboty")


dialogId("sp-m-nechat", "font_small", "What if we just leave that plug here?")
dialogStr("A może zostawmy tu ten korek?")


dialogId("sp-v-centrala", "font_big", "What would the Agency say?")
dialogStr("Co na to powie Centrala?")


dialogId("sp-v-jedno", "font_big", "I don’t think I mind what the boss is going to think about me.")
dialogStr("Nie dbam o to, co szef o mnie myśli.")


dialogId("sp-m-vydrz", "font_small", "Hold on. We are sure to solve it.")
dialogStr("Zaczekaj. Jestem pewna, że to rozwiążemy.")


dialogId("sp-m-spunt", "font_small", "The darned plug. What if we just make up something.")
dialogStr("Cholerny korek. Może po prostu coś zmyślimy?")


dialogId("sp-v-co", "font_big", "Like what, for example?")
dialogStr("Na przykład co?")


dialogId("sp-m-vymluva0", "font_small", "Well, we could say that the city in fact never existed.")
dialogStr("Moglibyśmy powiedzieć, że tak naprawdę miasto nigdy nie istniało.")


dialogId("sp-m-vymluva1", "font_small", "Well, we could say that the city sank because the Arctic ice had melted.")
dialogStr("Moglibyśmy powiedzieć, że miasto zatonęło w wyniku topnienia lądolodu Arktyki.")


dialogId("sp-m-vymluva2", "font_small", "An earthquake could have sunk the city, for example.")
dialogStr("Na przykład trzęsienie ziemi mogło zatopić miasto.")


dialogId("sp-m-vymluva3", "font_small", "A tsunami might have sunk the city, for example.")
dialogStr("Na przykład tsunami mogło zatopić miasto.")


dialogId("sp-m-vymluva4", "font_small", "We could try to say that a volcano erupted in the center of the city.")
dialogStr("Moglibyśmy powiedzieć, że w samym środku miasta wybuchł wulkan.")


dialogId("sp-v-nesmysl", "font_big", "That is just nonsense.")
dialogStr("Bez sensu.")


dialogId("sp-v-ven", "font_big", "This time our goal is to get that plug out.")
dialogStr("Tym razem naszym zadaniem jest wydostać stąd ten korek.")
